==> kbarcode-trinity-3.5.13.2.tar.xz: kbarcode-trinity-3.5.13.2/kbarcode/encodingcombo.cpp <==
/***************************************************************************
                          encodingcombo.h  -  description
                             -------------------
    begin                : Fri Dec 23 2005
    copyright            : (C) 2005 by Dominik Seichter
    email                : domseichter@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "encodingcombo.h"

#include <kcharsets.h>
#include <kglobal.h>
#include <klocale.h>
#include <tqtextcodec.h>

EncodingCombo::EncodingCombo( TQWidget* parent )
    : KComboBox( parent )
{
    TQString sEncoding = TQString( KGlobal::locale()->encoding() );
    TQStringList encodings (KGlobal::charsets()->availableEncodingNames());

    this->insertStringList( encodings );

    for (int i=0; i < encodings.count(); i++)
    {
        bool found = false;
        TQTextCodec *codecForEnc = KGlobal::charsets()->codecForName(encodings[i], found);
        if (found && ( (codecForEnc->name() == sEncoding) || (encodings[i] == sEncoding) ) )
        {
            this->setCurrentItem(i);
            break;
        }
    }
}

EncodingCombo::~EncodingCombo()
{
}

==> kbarcode-trinity_14.0.5.orig.tar.xz: kbarcode-trinity-14.0.5/kbarcode/encodingcombo.cpp <==
/***************************************************************************
                          encodingcombo.h  -  description
                             -------------------
    begin                : Fri Dec 23 2005
    copyright            : (C) 2005 by Dominik Seichter
    email                : domseichter@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "encodingcombo.h"

#include <kcharsets.h>
#include <tdeglobal.h>
#include <tdelocale.h>
#include <tqtextcodec.h>

EncodingCombo::EncodingCombo( TQWidget* parent )
    : KComboBox( parent )
{
    TQString sEncoding = TQString( TDEGlobal::locale()->encoding() );
    TQStringList encodings (TDEGlobal::charsets()->availableEncodingNames());

    this->insertStringList( encodings );

    for (int i=0; i < encodings.count(); i++)
    {
        bool found = false;
        TQTextCodec *codecForEnc = TDEGlobal::charsets()->codecForName(encodings[i], found);
        if (found && ( (codecForEnc->name() == sEncoding) || (encodings[i] == sEncoding) ) )
        {
            this->setCurrentItem(i);
            break;
        }
    }
}

EncodingCombo::~EncodingCombo()
{
}
